aboutsummaryrefslogtreecommitdiff
path: root/ratatoeskr/sys/plugin_api.php
diff options
context:
space:
mode:
authorKevin Chabowski <kevin@kch42.de>2011-09-21 17:00:50 +0200
committerKevin Chabowski <kevin@kch42.de>2011-09-21 17:00:50 +0200
commit8311cba002dfcaf1836530b978f944f7228ac004 (patch)
treed8ff9eac15957194a53e4c6e94d4bd9eb2d89c2d /ratatoeskr/sys/plugin_api.php
parenta85e1fbbfbbaef176141e98a4691273cd06d0a65 (diff)
downloadratatoeskr-cms-8311cba002dfcaf1836530b978f944f7228ac004.tar.gz
ratatoeskr-cms-8311cba002dfcaf1836530b978f944f7228ac004.tar.bz2
ratatoeskr-cms-8311cba002dfcaf1836530b978f944f7228ac004.zip
Replaced Smarty with STE and started the backend.
Diffstat (limited to 'ratatoeskr/sys/plugin_api.php')
-rw-r--r--ratatoeskr/sys/plugin_api.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/ratatoeskr/sys/plugin_api.php b/ratatoeskr/sys/plugin_api.php
index 65e4c9c..6293c27 100644
--- a/ratatoeskr/sys/plugin_api.php
+++ b/ratatoeskr/sys/plugin_api.php
@@ -38,10 +38,10 @@ abstract class RatatoeskrPlugin
* Variables: Protected variables
*
* $kvstorage - The Key-Value-Storage for the Plugin.
* $smarty - Access to the global smarty object.
*/
protected $kvstorage;
- protected $smarty;
+ protected $ste;
/*
@@ -54,11 +54,11 @@ abstract class RatatoeskrPlugin
*/
public function __construct($id)
{
- global $smarty;
+ global $ste;
$this->id = $id;
$this->kvstorage = new PluginKVStorage($id);
- $this->smarty = $smarty;
+ $this->ste = $ste;
}
/*
@@ -70,7 +70,7 @@ abstract class RatatoeskrPlugin
*/
final public function get_id() { return $this->id; }
final protected function get_additional_files_dir() { return dirname(dirname(__FILE__)) . "/plugin_extradata/" . $this->id; }
- final protected function get_template_dir() { return dirname(dirname(__FILE__)) . "/templates/plugintemplates/" . $this->id; }
+ final protected function get_template_dir() { return dirname(dirname(__FILE__)) . "/templates/src/plugintemplates/" . $this->id; }
/*
* Function: register_url_handler
@@ -85,7 +85,7 @@ abstract class RatatoeskrPlugin
register_url_handler($name, array($this, $objfunction));
}
- final protected function register_settings_page($get, $validate, $set, $structure)
+ /*final protected function register_settings_page($get, $validate, $set, $structure)*/
/*
* Functions: Functions that are called at special events
@@ -38,10 +38,10 @@ abstract class RatatoeskrPlugin
*
* $kvstorage - The Key-Value-Storage for the Plugin.
- * $smarty - Access to the global smarty object.
+ * $ste - Access to the global STECore object.
*/
protected $kvstorage;